@@ -8,13 +8,15 @@ from enterprise.signals import signal_base
 
 @signal_base.function
 def param_hd_orf(pos1, pos2, a=1.5, b=-0.25, c=0.5):
-    '''Pre-factor parametrized Hellings & Downs spatial correlation function.
+    '''
+    Pre-factor parametrized Hellings & Downs spatial correlation function.
 
     :param: a, b, c:
         coefficients of H&D-like curve [default=1.5,-0.25,0.5].
 
     Reference: Taylor, Gair, Lentati (2013), https://arxiv.org/abs/1210.6014
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1
@@ -26,7 +28,8 @@ def param_hd_orf(pos1, pos2, a=1.5, b=-0.25, c=0.5):
 
 @signal_base.function
 def spline_orf(pos1, pos2, params):
-    '''Agnostic spline-interpolated spatial correlation function. Spline knots
+    '''
+    Agnostic spline-interpolated spatial correlation function. Spline knots
     are placed at edges, zeros, and minimum of H&D curve. Changing locations
     will require manual intervention to create new function.
 
@@ -35,6 +38,7 @@ def spline_orf(pos1, pos2, params):
 
     Reference: Taylor, Gair, Lentati (2013), https://arxiv.org/abs/1210.6014
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1
@@ -51,7 +55,8 @@ def spline_orf(pos1, pos2, params):
 
 @signal_base.function
 def bin_orf(pos1, pos2, params):
-    '''Agnostic binned spatial correlation function. Bin edges are
+    '''
+    Agnostic binned spatial correlation function. Bin edges are
     placed at edges and across angular separation space. Changing bin
     edges will require manual intervention to create new function.
 
@@ -59,6 +64,7 @@ def bin_orf(pos1, pos2, params):
         inter-pulsar correlation bin amplitudes.
 
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1
@@ -73,7 +79,8 @@ def bin_orf(pos1, pos2, params):
 
 @signal_base.function
 def zero_diag_bin_orf(pos1, pos2, params):
-    '''Agnostic binned spatial correlation function. To be
+    '''
+    Agnostic binned spatial correlation function. To be
     used in a "split likelihood" model with an additional common
     uncorrelated red process. The latter is necessary to regularize
     the overall Phi covariance matrix.
@@ -82,6 +89,7 @@ def zero_diag_bin_orf(pos1, pos2, params):
         inter-pulsar correlation bin amplitudes.
 
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1e-20
@@ -96,12 +104,14 @@ def zero_diag_bin_orf(pos1, pos2, params):
 
 @signal_base.function
 def zero_diag_hd(pos1, pos2):
-    '''Off-diagonal Hellings & Downs spatial correlation function. To be
+    '''
+    Off-diagonal Hellings & Downs spatial correlation function. To be
     used in a "split likelihood" model with an additional common uncorrelated
     red process. The latter is necessary to regularize the overall Phi
     covariance matrix.
 
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1e-20
@@ -112,7 +122,8 @@ def zero_diag_hd(pos1, pos2):
 
 @signal_base.function
 def freq_hd(pos1, pos2, params):
-    '''Frequency-dependent Hellings & Downs spatial correlation function.
+    '''
+    Frequency-dependent Hellings & Downs spatial correlation function.
     Implemented as a model that only enforces H&D inter-pulsar correlations
     after a certain number of frequencies in the spectrum. The first set of
     frequencies are uncorrelated.
@@ -124,6 +135,7 @@ def freq_hd(pos1, pos2, params):
 
     Reference: Taylor et al. (2017), https://arxiv.org/abs/1606.09180
     Author: S. R. Taylor (2020)
+
     '''
     nfreq = params[0]
     orf_ifreq = params[1]
@@ -139,7 +151,8 @@ def freq_hd(pos1, pos2, params):
 
 @signal_base.function
 def legendre_orf(pos1, pos2, params):
-    '''Legendre polynomial spatial correlation function. Assumes process
+    '''
+    Legendre polynomial spatial correlation function. Assumes process
     normalization such that autocorrelation signature is 1. A separate function
     is needed to use a "split likelihood" model with this Legendre process
     decoupled from the autocorrelation signature ("zero_diag_legendre_orf").
@@ -151,6 +164,7 @@ def legendre_orf(pos1, pos2, params):
 
     Reference: Gair et al. (2014), https://arxiv.org/abs/1406.4664
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1
@@ -162,7 +176,8 @@ def legendre_orf(pos1, pos2, params):
 
 @signal_base.function
 def zero_diag_legendre_orf(pos1, pos2, params):
-    '''Legendre polynomial spatial correlation function. To be
+    '''
+    Legendre polynomial spatial correlation function. To be
     used in a "split likelihood" model with an additional common uncorrelated
     red process. The latter is necessary to regularize the overall Phi
     covariance matrix.
@@ -174,6 +189,7 @@ def zero_diag_legendre_orf(pos1, pos2, params):
 
     Reference: Gair et al. (2014), https://arxiv.org/abs/1406.4664
     Author: S. R. Taylor (2020)
+
     '''
     if np.all(pos1 == pos2):
         return 1e-20
@@ -276,7 +292,9 @@ def gt_orf(pos1, pos2, tau):
 
     :param: tau
         tau = 1 results in ST correlations while tau = -1 results in HD correlations.
+
     Author: N. Laal (2020)
+
     """
     if np.all(pos1 == pos2):
         return 1
@@ -293,6 +311,7 @@ def generalized_gwpol_psd(f, log10_A_tt=-15, log10_A_st=-15, alpha_tt=-2/3, alph
     General powerlaw spectrum allowing for existence of all possible modes of gravity as
     predicted by a general metric spacetime theory and generated by a binary system.
     The SL and VL modes' powerlaw relations are not normalized.
+
     :param: f
         A list of considered frequencies
     :param: log10_A_tt
@@ -314,6 +333,7 @@ def generalized_gwpol_psd(f, log10_A_tt=-15, log10_A_st=-15, alpha_tt=-2/3, alph
 
     Reference: Cornish et al. (2017), https://arxiv.org/abs/1712.07132
     Author: S. R. Taylor, N. Laal (2020)
+
     '''
 
     df = np.diff(np.concatenate((np.array([0]), f[::2])))
