@@ -10,11 +10,121 @@ import numpy as np
 from PTMCMCSampler.PTMCMCSampler import PTSampler as ptmcmc
 
 from enterprise_extensions import __version__
+from enterprise_extensions.empirical_distr import (EmpiricalDistribution1D,
+                                                   EmpiricalDistribution1DKDE,
+                                                   EmpiricalDistribution2D,
+                                                   EmpiricalDistribution2DKDE)
+
+
+def extend_emp_dists(pta, emp_dists, npoints=100_000, save_ext_dists=False, outdir='chains'):
+    new_emp_dists = []
+    modified = False  # check if anything was changed
+    for emp_dist in emp_dists:
+        if isinstance(emp_dist, EmpiricalDistribution2D) or isinstance(emp_dist, EmpiricalDistribution2DKDE):
+            # check if we need to extend the distribution
+            prior_ok=True
+            for ii, (param, nbins) in enumerate(zip(emp_dist.param_names, emp_dist._Nbins)):
+                if param not in pta.param_names:  # skip if one of the parameters isn't in our PTA object
+                    continue
+                # check 2 conditions on both params to make sure that they cover their priors
+                # skip if emp dist already covers the prior
+                param_idx = pta.param_names.index(param)
+                prior_min = pta.params[param_idx].prior._defaults['pmin']
+                prior_max = pta.params[param_idx].prior._defaults['pmax']
+
+                # no need to extend if histogram edges are already prior min/max
+                if isinstance(emp_dist, EmpiricalDistribution2D):
+                    if not(emp_dist._edges[ii][0] == prior_min and emp_dist._edges[ii][-1] == prior_max):
+                        prior_ok = False
+                        continue
+                elif isinstance(emp_dist, EmpiricalDistribution2DKDE):
+                    if not(emp_dist.minvals[ii] == prior_min and emp_dist.maxvals[ii] == prior_max):
+                        prior_ok=False
+                        continue
+            if prior_ok:
+                new_emp_dists.append(emp_dist)
+                continue
+            modified = True
+            samples = np.zeros((npoints, emp_dist.draw().shape[0]))
+            for ii in range(npoints):  # generate samples from old emp dist
+                samples[ii] = emp_dist.draw()
+            new_bins = []
+            minvals = []
+            maxvals = []
+            idxs_to_remove = []
+            for ii, (param, nbins) in enumerate(zip(emp_dist.param_names, emp_dist._Nbins)):
+                param_idx = pta.param_names.index(param)
+                prior_min = pta.params[param_idx].prior._defaults['pmin']
+                prior_max = pta.params[param_idx].prior._defaults['pmax']
+                # drop samples that are outside the prior range (in case prior is smaller than samples)
+                if isinstance(emp_dist, EmpiricalDistribution2D):
+                    samples[(samples[:, ii] < prior_min) | (samples[:, ii] > prior_max), ii] = -np.inf
+                elif isinstance(emp_dist, EmpiricalDistribution2DKDE):
+                    idxs_to_remove.extend(np.arange(npoints)[(samples[:, ii] < prior_min) | (samples[:, ii] > prior_max)])
+                    minvals.append(prior_min)
+                    maxvals.append(prior_max)
+                # new distribution with more bins this time to extend it all the way out in same style as above.
+                new_bins.append(np.linspace(prior_min, prior_max, nbins + 40))
+            samples = np.delete(samples, idxs_to_remove, axis=0)
+            if isinstance(emp_dist, EmpiricalDistribution2D):
+                new_emp = EmpiricalDistribution2D(emp_dist.param_names, samples.T, new_bins)
+            elif isinstance(emp_dist, EmpiricalDistribution2DKDE):
+                # new distribution with more bins this time to extend it all the way out in same style as above.
+                new_emp = EmpiricalDistribution2DKDE(emp_dist.param_names, samples.T, minvals=minvals, maxvals=maxvals, nbins=nbins+40, bandwidth=emp_dist.bandwidth)
+            new_emp_dists.append(new_emp)
+
+        elif isinstance(emp_dist, EmpiricalDistribution1D) or isinstance(emp_dist, EmpiricalDistribution1DKDE):
+            if emp_dist.param_name not in pta.param_names:
+                continue
+            param_idx = pta.param_names.index(emp_dist.param_name)
+            prior_min = pta.params[param_idx].prior._defaults['pmin']
+            prior_max = pta.params[param_idx].prior._defaults['pmax']
+            # check 2 conditions on param to make sure that it covers the prior
+            # skip if emp dist already covers the prior
+            if isinstance(emp_dist, EmpiricalDistribution1D):
+                if emp_dist._edges[0] == prior_min and emp_dist._edges[-1] == prior_max:
+                    new_emp_dists.append(emp_dist)
+                    continue
+            elif isinstance(emp_dist, EmpiricalDistribution1DKDE):
+                if emp_dist.minval == prior_min and emp_dist.maxval == prior_max:
+                    new_emp_dists.append(emp_dist)
+                    continue
+            modified = True
+            samples = np.zeros((npoints, 1))
+            for ii in range(npoints):  # generate samples from old emp dist
+                samples[ii] = emp_dist.draw()
+            new_bins = []
+            idxs_to_remove = []
+            # drop samples that are outside the prior range (in case prior is smaller than samples)
+
+            if isinstance(emp_dist, EmpiricalDistribution1D):
+                samples[(samples < prior_min) | (samples > prior_max)] = -np.inf
+            elif isinstance(emp_dist, EmpiricalDistribution1DKDE):
+                idxs_to_remove.extend(np.arange(npoints)[(samples.squeeze() < prior_min) | (samples.squeeze() > prior_max)])
+
+            samples = np.delete(samples, idxs_to_remove, axis=0)
+            new_bins = np.linspace(prior_min, prior_max, emp_dist._Nbins + 40)
+            if isinstance(emp_dist, EmpiricalDistribution1D):
+                new_emp = EmpiricalDistribution1D(emp_dist.param_name, samples, new_bins)
+            elif isinstance(emp_dist, EmpiricalDistribution1DKDE):
+                new_emp = EmpiricalDistribution1DKDE(emp_dist.param_name, samples,
+                                                     minval=prior_min, maxval=prior_max,
+                                                     bandwidth=emp_dist.bandwidth)
+            new_emp_dists.append(new_emp)
+
+        else:
+            print('Unable to extend class of unknown type to the edges of the priors.')
+            new_emp_dists.append(emp_dist)
+            continue
+
+        if save_ext_dists and modified:  # if user wants to save them, and they have been modified...
+            pickle.dump(new_emp_dists, outdir + 'new_emp_dists.pkl')
+    return new_emp_dists
 
 
 class JumpProposal(object):
 
-    def __init__(self, pta, snames=None, empirical_distr=None, f_stat_file=None):
+    def __init__(self, pta, snames=None, empirical_distr=None, f_stat_file=None, save_ext_dists=False, outdir='chains'):
         """Set up some custom jump proposals"""
         self.params = pta.params
         self.pnames = pta.param_names
@@ -110,8 +220,12 @@ class JumpProposal(object):
                 else:
                     if d.param_names[0] in pta.param_names and d.param_names[1] in pta.param_names:
                         mask.append(idx)
-            if len(mask) > 1:
+            if len(mask) >= 1:
                 self.empirical_distr = [self.empirical_distr[m] for m in mask]
+                # extend empirical_distr here:
+                print('Extending empirical distributions to priors...\n')
+                self.empirical_distr = extend_emp_dists(pta, self.empirical_distr, npoints=100_000,
+                                                        save_ext_dists=save_ext_dists, outdir=outdir)
             else:
                 self.empirical_distr = None
 
@@ -193,17 +307,25 @@ class JumpProposal(object):
                 lqxy = (self.empirical_distr[distr_idx].logprob(x[idx]) -
                         self.empirical_distr[distr_idx].logprob(q[idx]))
 
+                dist = self.empirical_distr[distr_idx]
+                # if we fall outside the emp distr support, pull from prior instead
+                if x[idx] < dist._edges[0] or x[idx] > dist._edges[-1]:
+                    q, lqxy = self.draw_from_prior(x, iter, beta)
+
             else:
+                dist = self.empirical_distr[distr_idx]
+                oldsample = [x[self.pnames.index(p)] for p in dist.param_names]
+                newsample = dist.draw()
 
-                oldsample = [x[self.pnames.index(p)]
-                             for p in self.empirical_distr[distr_idx].param_names]
-                newsample = self.empirical_distr[distr_idx].draw()
+                lqxy = (dist.logprob(oldsample) - dist.logprob(newsample))
 
-                for p, n in zip(self.empirical_distr[distr_idx].param_names, newsample):
+                for p, n in zip(dist.param_names, newsample):
                     q[self.pnames.index(p)] = n
 
-                lqxy = (self.empirical_distr[distr_idx].logprob(oldsample) -
-                        self.empirical_distr[distr_idx].logprob(newsample))
+                # if we fall outside the emp distr support, pull from prior instead
+                for ii in range(len(oldsample)):
+                    if oldsample[ii] < dist._edges[ii][0] or oldsample[ii] > dist._edges[ii][-1]:
+                        q, lqxy = self.draw_from_prior(x, iter, beta)
 
         return q, float(lqxy)
 
@@ -369,16 +491,21 @@ class JumpProposal(object):
     def draw_from_gwb_log_uniform_distribution(self, x, iter, beta):
 
         q = x.copy()
+        lqxy = 0
 
         # draw parameter from signal model
-        gw_pars = [par for par in self.pnames
-                   if ('gw' in par and 'log10_A' in par)]
-        gw_par = np.random.choice(gw_pars)
-        idx = self.pnames.index(gw_par)
+        signal_name = [par for par in self.pnames
+                       if ('gw' in par and 'log10_A' in par)][0]
+        idx = list(self.pnames).index(signal_name)
+        param = self.params[idx]
 
-        q[idx] = np.random.uniform(-18, -14)
+        q[self.pmap[str(param)]] = np.random.uniform(param.prior._defaults['pmin'], param.prior._defaults['pmax'])
 
-        return q, 0
+        # forward-backward jump probability
+        lqxy = (param.get_logpdf(x[self.pmap[str(param)]]) -
+                param.get_logpdf(q[self.pmap[str(param)]]))
+
+        return q, float(lqxy)
 
     def draw_from_dipole_log_uniform_distribution(self, x, iter, beta):
 
@@ -895,7 +1022,8 @@ def save_runtime_info(pta, outdir='chains', human=None):
 
 
 def setup_sampler(pta, outdir='chains', resume=False,
-                  empirical_distr=None, groups=None, human=None):
+                  empirical_distr=None, groups=None, human=None,
+                  save_ext_dists=False, loglkwargs={}, logpkwargs={}):
     """
     Sets up an instance of PTMCMC sampler.
 
@@ -913,6 +1041,11 @@ def setup_sampler(pta, outdir='chains', resume=False,
     whether or not certain parameters are in the model. These are
     all either draws from the prior distribution of parameters or
     draws from uniform distributions.
+
+    save_ext_dists: saves distributions that have been extended to
+    cover priors as a pickle to the outdir folder. These can then
+    be loaded later as distributions to save a minute at the start
+    of the run.
     """
 
     # dimension of parameter space
@@ -930,12 +1063,13 @@ def setup_sampler(pta, outdir='chains', resume=False,
         groups = get_parameter_groups(pta)
 
     sampler = ptmcmc(ndim, pta.get_lnlikelihood, pta.get_lnprior, cov, groups=groups,
-                     outDir=outdir, resume=resume)
+                     outDir=outdir, resume=resume, loglkwargs=loglkwargs,
+                     logpkwargs=logpkwargs)
 
     save_runtime_info(pta, sampler.outDir, human)
 
     # additional jump proposals
-    jp = JumpProposal(pta, empirical_distr=empirical_distr)
+    jp = JumpProposal(pta, empirical_distr=empirical_distr, save_ext_dists=save_ext_dists, outdir=outdir)
     sampler.jp = jp
 
     # always add draw from prior
