@@ -71,8 +71,9 @@ def get_scrambles(psrs, N=500, Nmax=10000, thresh=0.1,
     :param Nmax: Maximum number of tries to get independent scrambles
     :param thresh: Threshold value for match statistic.
     :param filename: Name of the file where the sky scrambles should be saved.
-                     Sky scrambles should be saved in *.npz file.
+        Sky scrambles should be saved in `npz` file.
     :param resume: Whether to resume from an earlier run.
+
     """
 
     # compute the unscrambled ORF
